@@ -14,6 +14,7 @@ import requests
 from cement import init_defaults
 from requests.auth import AuthBase
 
+from banyan.core.exc import BanyanError
 from banyan.api.attachment import AttachmentAPI
 from banyan.api.audit import AuditAPI
 from banyan.api.device import DeviceAPI
@@ -27,7 +28,10 @@ from banyan.api.service_infra import ServiceInfraAPI
 from banyan.api.shield import ShieldAPI
 from banyan.api.user import UserAPI
 from banyan.api.cloud_resource import CloudResourceAPI
-from banyan.core.exc import BanyanError
+from banyan.api.api_key import ApiKeyAPI
+from banyan.api.connector import ConnectorAPI
+from banyan.api.access_tier import AccessTierAPI
+from banyan.api.service_tunnel import ServiceTunnelAPI
 
 JsonListOrObj = Union[List, Dict]
 ProgressCallback = Callable[[str, str, int, int, List[JsonListOrObj]], None]
@@ -37,16 +41,16 @@ class BanyanApiClient:
     """
     Main class for interacting with the Banyan API.
 
-    :param api_server_url: URL for the Banyan Command Center. This should be the same as the
+    :param api_url: URL for the Banyan Command Center. This should be the same as the
         URL you enter in your browser to log into the Command Center. If not supplied, we will
-        look for an environment variable named :envvar:`BANYAN_API_URL`; if that is also not present,
-        the URL defaults to <https://net.banyanops.com>.
-    :type api_server_url: str
-    :param refresh_token: Initial API token used to authorize the connection. The refresh token
-        will then be exchanged for an access token. If not supplied, we look for an environment
-        varialbe named :envvar:`BANYAN_REFRESH_TOKEN`; if that is also not present, it causes a
-        :py:exc:`BanyanError`.
-    :type refresh_token: str
+        look for an environment variable named :envvar:`BANYAN_API_URL`; 
+        if that is also not present, the URL defaults to <https://net.banyanops.com>.
+    :type api_url: str
+    :param api_key: Initial API credential used to authorize the connection - can be an api key or
+        a refresh token (that will then be exchanged for an access token). If not supplied, we will
+        look for an environment variable named :envvar:`BANYAN_API_KEY` or :envvar:`BANYAN_REFRESH_TOKEN`; 
+        if that is also not present, it causes a :py:exc:`BanyanError`.
+    :type api_key: str
     :param debug: If True, extra debugging output from the Requests module will be logged.
     :type debug: bool
     :param log: Optional logger to use in debug mode. If not provided, the standard
@@ -80,20 +84,20 @@ class BanyanApiClient:
             r.headers['Authorization'] = f'Bearer {token}'
             return r
 
-    def __init__(self, api_server_url: str = None, refresh_token: str = None, debug: bool = False,
+    def __init__(self, api_url: str = None, api_key: str = None, debug: bool = False,
                  log: logging.Logger = None) -> None:
         self._debug = debug
         self._log = log
         self._progress_callback = None
         self._access_token = None
         self._insecure_tls = False
-        self._api_url = self._normalize_url(api_server_url or os.getenv('BANYAN_API_URL') or
-                                            BanyanApiClient.DEFAULT_API_URL)
-        self._refresh_token = refresh_token or os.getenv('BANYAN_REFRESH_TOKEN')
+        self._api_url = self._normalize_url(api_url or 
+                                            os.getenv('BANYAN_API_URL') or BanyanApiClient.DEFAULT_API_URL)
+        self._refresh_token = api_key or os.getenv('BANYAN_API_KEY') or os.getenv('BANYAN_REFRESH_TOKEN')
         if not self._refresh_token:
             self._read_config_file()
         if not self._refresh_token:
-            raise BanyanError("Refresh token must be set")
+            raise BanyanError("A api_key (API Key or Refresh Token) must be set")
         if self._debug:
             requests_log = logging.getLogger('requests.packages.urllib3')
             requests_log.setLevel(logging.DEBUG)
@@ -112,6 +116,10 @@ class BanyanApiClient:
         self._cloud_resources = CloudResourceAPI(self)
         self._services_web = ServiceWebAPI(self)
         self._services_infra = ServiceInfraAPI(self)
+        self._api_keys = ApiKeyAPI(self)
+        self._connectors = ConnectorAPI(self)
+        self._access_tiers = AccessTierAPI(self)
+        self._service_tunnels = ServiceTunnelAPI(self)
 
     def __del__(self):
         if self._http:
@@ -129,7 +137,7 @@ class BanyanApiClient:
                 cp = configparser.ConfigParser(CONFIG)
                 cp.read(conf_path)
                 self._api_url = self._normalize_url(cp.get('banyan', 'api_url'))
-                self._refresh_token = cp.get('banyan', 'refresh_token')
+                self._refresh_token = cp.get('banyan', 'api_key') or cp.get('banyan', 'refresh_token')
             except configparser.Error:
                 pass
 
@@ -262,6 +270,7 @@ class BanyanApiClient:
         params = params or dict()
         skip = params.get('skip', 0)
         limit = params.get('limit', 1000)
+        search_uri = uri + "s"  # support plurals /v2/satellite -> satellites
         all_results = list()
         callback = progress_callback or self._progress_callback
 
@@ -270,8 +279,8 @@ class BanyanApiClient:
             params['limit'] = limit
             results = self.api_request(method, uri, params, data, json, headers, accept)
             for key in results.keys():
-                logging.debug('Looking for %s in %s', key, uri)
-                if key in uri or key == 'data' or key == 'result':
+                logging.debug('Looking for %s in %s', key, search_uri)
+                if key in search_uri or key == 'data' or key == 'result':
                     if len(results[key]) == 0:
                         return all_results
                     all_results.extend(results[key])
@@ -410,17 +419,33 @@ class BanyanApiClient:
     def cloud_resources(self) -> CloudResourceAPI:
         return self._cloud_resources
 
+    @property
+    def api_keys(self) -> ApiKeyAPI:
+        return self._api_keys
+
+    @property
+    def connectors(self) -> ConnectorAPI:
+        return self._connectors
+
+    @property
+    def access_tiers(self) -> AccessTierAPI:
+        return self._access_tiers
+
+    @property
+    def service_tunnels(self) -> ServiceTunnelAPI:
+        return self._service_tunnels
 
 # configuration defaults
 CONFIG = init_defaults('banyan')
 CONFIG['banyan']['api_url'] = BanyanApiClient.DEFAULT_API_URL
 CONFIG['banyan']['refresh_token'] = None
+CONFIG['banyan']['api_key'] = None
 
 
 if __name__ == '__main__':
     logging.basicConfig(level=logging.DEBUG)
 
-    c = BanyanApiClient(api_server_url='https://gcstage.banyanops.com',
-                        refresh_token=os.getenv('BANYAN_REFRESH_TOKEN'), debug=True)
+    c = BanyanApiClient(api_url='https://preview.console.banyanops.com',
+                        refresh_token=os.getenv('BANYAN_API_KEY'), debug=True)
     print(c.get_access_token())
     print(c.services.list())
