@@ -1,10 +1,8 @@
-from typing import List
-
 from cement import Controller, ex
 
 from banyan.api import DeviceAPI
 from banyan.controllers.base import Base
-from banyan.model.user_device import Device, TrustScore, TrustLevel
+from banyan.model.user_device import Device, DeviceV2, TrustScore, TrustLevel
 
 
 class DeviceController(Controller):
@@ -20,12 +18,13 @@ class DeviceController(Controller):
 
     @ex(help='list devices')
     def list(self):
-        devices: List[Device] = self._client.list()
+        devices = self._client.list()
         results = list()
-        headers = ['Device Name', 'Serial Number', 'Platform', 'Ownership', 'Trust Score', 'Banned', 'Last Login']
+        headers = ['Device Name', 'Serial Number', 'Platform', 'Ownership', 'MDM', 'MDM Vendor', 'Trust Level', 'Trust Status', 'Last Login']
         for device in devices:
-            new_row = [device.device_friendly_name, device.serial_number, device.platform,
-                       device.ownership, device.trust_data.level, device.is_banned,
+            new_row = [Base.trunc(device.device_friendly_name, 8, True), device.serial_number, device.platform,
+                       device.ownership, device.mdm_present, device.mdm_vendor_name,
+                       device.trust_level, device.trust_status,
                        device.last_login.strftime(Base.TABLE_DATE_FORMAT) if device.last_login else 'None']
             results.append(new_row)
         results.sort(key=lambda x: x[0])
@@ -41,14 +40,37 @@ class DeviceController(Controller):
     def get(self):
         serial_number = self.app.pargs.serial_number
         device = self._client.find(serial_number)
-        device_json = Device.Schema().dump(device)
+        device_json = DeviceV2.Schema().dump(device)
         # colorized_json = highlight(policy_json, lexers.JsonLexer(), formatters.Terminal256Formatter(style="default"))
         self.app.render(device_json, handler='json', indent=2, sort_keys=True)
 
-    # TODO: implement /mdm/update_device?SerialNumber=X
-    @ex(help='update device status')
+    @ex(help='update device attributes to set MDM vendor presence',
+        arguments=[
+            (['serial_number'],
+             {
+                 'help': 'Serial number of the device.'
+             }),
+             (['--mdm_present'], 
+             {
+                 'required': True,
+                 'choices': ["true", "True", "false", "False"],
+                 'help': 'Set MDM present to true/false.'
+             }),
+             (['--mdm_vendor_name'],
+             {
+                 'required': True,        
+                 'help': 'Set MDM vendor name.'        
+             })
+        ])        
     def update(self):
-        pass
+        # get the device first
+        serial_number = self.app.pargs.serial_number
+        device = self._client.find(serial_number)
+        device.mdm_present = self.app.pargs.mdm_present.lower() == "true"
+        device.mdm_vendor_name = self.app.pargs.mdm_vendor_name
+        print(self._client.update(device))
+        device_json = DeviceV2.Schema().dump(device)
+        self.app.render(device_json, handler='json', indent=2, sort_keys=True)
 
     # TODO: implement /delete_device?Email=X&SerialNumber=Y
     @ex(help='delete a device')
