@@ -19,18 +19,26 @@ from banyan.controllers.service_infra import ServiceInfraController
 from banyan.controllers.shield import ShieldController
 from banyan.controllers.user import UserController
 from banyan.controllers.cloud_resource import CloudResourceController
+from banyan.controllers.api_key import ApiKeyController
+from banyan.controllers.connector import ConnectorController
+from banyan.controllers.access_tier import AccessTierController
+from banyan.controllers.service_tunnel import ServiceTunnelController
+
 from .core.exc import BanyanError
 
 # configuration defaults
 CONFIG = init_defaults('banyan')
 CONFIG['banyan']['api_url'] = BanyanApiClient.DEFAULT_API_URL
 CONFIG['banyan']['refresh_token'] = None
+CONFIG['banyan']['api_key'] = None
 
 
 def extend_client(app: App) -> None:
     api_url = app.config.get('banyan', 'api_url')
     refresh_token = app.config.get('banyan', 'refresh_token')
-    client = BanyanApiClient(api_url, refresh_token, debug=app.debug)
+    api_key = app.config.get('banyan', 'api_key')
+    credential = api_key or refresh_token
+    client = BanyanApiClient(api_url, credential, debug=app.debug)
     app.extend('client', client)
 
 
@@ -82,20 +90,23 @@ class MyApp(App):
         # register handlers
         handlers = [
             Base,
-            CloudResourceController,
-            ServiceInfraController,
+            UserController,
             ServiceWebController,
-            ServiceController,
+            ServiceTunnelController,
+            ServiceInfraController,
             RoleController,
             PolicyController,
-            ShieldController,
-            NetagentController,
-            UserController,
-            DeviceController,
-            AdminController,
+            ExportController,
             EventV2Controller,
+            DeviceController,
+            ConnectorController,
+            CloudResourceController,
             AuditController,
-            ExportController
+            ApiKeyController,
+            AccessTierController,
+            ShieldController,
+            ServiceController,
+            NetagentController,
         ]
 
 
