@@ -2,17 +2,15 @@ from abc import ABC
 from dataclasses import field
 from datetime import datetime
 from ipaddress import IPv4Interface
-from typing import ClassVar, Type, Union
+from typing import ClassVar, Type, Union, Optional
 
 from aenum import StrEnum
-from marshmallow import fields, Schema
+from marshmallow import fields, Schema, post_dump
 from marshmallow_dataclass import dataclass
 from semver import VersionInfo
 
 from banyan.core.exc import BanyanError
 
-API_VERSION = "rbac.banyanops.com/v1"
-
 
 class BanyanEnum(StrEnum):
 
@@ -27,7 +25,10 @@ class TimestampField(fields.DateTime):
         if not value:
             return None
         elif isinstance(value, int):
-            return datetime.fromtimestamp(value)
+            try:
+                return datetime.fromtimestamp(value)
+            except OSError:
+                return None
         else:
             return super()._deserialize(value, attr, data, **kwargs)
 
@@ -45,7 +46,10 @@ class NanoTimestampField(fields.DateTime):
         if not value:
             return None
         elif isinstance(value, int):
-            return datetime.fromtimestamp(value / 1000000000)
+            try:
+                return datetime.fromtimestamp(value / 1000000000)
+            except Exception as ex:
+                raise ValueError(f'{ex.args[0]}, value = {value}, attr = {attr}')
         else:
             return super()._deserialize(value, attr, data, **kwargs)
 
@@ -53,7 +57,10 @@ class NanoTimestampField(fields.DateTime):
         if not value:
             return 0
         elif isinstance(value, datetime):
-            return int(value.timestamp() * 1000000000)
+            try:
+                return int(value.timestamp() * 1000000000)
+            except OSError:
+                return 0
         else:
             return super()._serialize(value, attr, obj, **kwargs)
 
@@ -65,7 +72,7 @@ class MilliTimestampField(fields.DateTime):
         elif isinstance(value, int):
             try:
                 return datetime.fromtimestamp(value / 1000)
-            except ValueError as ex:
+            except Exception as ex:
                 raise ValueError(f'{ex.args[0]}, value = {value}, attr = {attr}')
         else:
             return super()._deserialize(value, attr, data, **kwargs)
@@ -84,7 +91,10 @@ class IPv4InterfaceField(fields.Field):
         if not value:
             return None
         elif isinstance(value, str):
-            return IPv4Interface(value)
+            try:
+                return IPv4Interface(value)
+            except Exception as ex:
+                raise ValueError(f'{ex.args[0]}, value = {value}, attr = {attr}')
         else:
             return super()._deserialize(value, attr, data, **kwargs)
 
@@ -104,7 +114,10 @@ class VersionField(fields.Field):
         elif isinstance(value, str):
             if '_' in value:
                 value = value.split('_')[0]
-            return VersionInfo.parse(value)
+            try:
+                return VersionInfo.parse(value)
+            except Exception as ex:
+                raise ValueError(f'{ex.args[0]}, value = {value}, attr = {attr}')
         else:
             return super()._deserialize(value, attr, data, **kwargs)
 
@@ -119,15 +132,19 @@ class VersionField(fields.Field):
 
 @dataclass
 class BanyanApiObject:
+    API_VERSION = "rbac.banyanops.com/v1"
     TYPE = "origin"
-    apiVersion: str
+    KIND = ""
+
+    apiVersion: Optional[str]
+    type: Optional[str]
     kind: str
-    type: str
     Schema: ClassVar[Type[Schema]] = Schema
 
     def __post_init__(self):
-        self.apiVersion = API_VERSION
+        self.apiVersion = self.API_VERSION
         self.type = self.TYPE
+        self.kind = self.KIND
 
     @property
     def name(self) -> str:
@@ -146,6 +163,17 @@ class Resource(ABC):
     def id(self) -> str:
         raise BanyanError('not implemented')
 
+    # noinspection PyUnusedLocal
+    @post_dump
+    def _remove_nulls(self, data, many, **kwargs):
+        new_data = dict()
+        for key, val in data.items():
+            if isinstance(val, dict):
+                new_data[key] = self._remove_nulls(val, False, **kwargs)
+            elif val is not None:
+                new_data[key] = val
+        return new_data
+
 
 ResourceOrName = Union[Resource, str]
 
